package db

import (
	"context"
	"errors"
	"fmt"
	"github.com/issue9/conv"
	"gorm.io/gorm"
	"strconv"
	"strings"
	"time"
	"youngee_m_api/model/gorm_model"
	"youngee_m_api/model/http_model"
)

func GetLocallifetaskList(ctx context.Context, request http_model.GetLocalTaskListRequest) (*http_model.GetLocalTaskListData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_status = ?", request.ProjectId, request.CoopType)
	fmt.Println(query)
	// 构建查询条件
	if request.FeeFrom != nil {
		query = query.Where("fee_form = ?", request.FeeFrom)
	}
	if request.Type != nil {
		switch *request.Type {
		case 1:
			query = query.Where("supplier_id = 0 AND supplier_status = 0")
		case 2:
			query = query.Where("supplier_id !=0 AND supplier_status = 2")
		}
	}
	if request.TalentFromList != "" {
		citylist := strings.Split(request.TalentFromList, ",")
		query = query.Where("city in ?", citylist)
	}
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize

	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocaLTaskInfo, 0, len(projecrtaskinfo))
	for _, task := range projecrtaskinfo {
		var Time time.Time
		switch request.CoopType {
		case 1:
			Time = task.CreateDate
		case 2:
			Time = task.SelectDate //2 signedtime
		case 3:
			Time = task.CompleteDate
		}
		boperator := getBOperator(db, task.BOperator, task.BOperatorType)
		nickname, headurl := getTalentinfo(db, task.TalentId)
		Iscoop := getIscoop(db, task.TalentId, request.EnterPriseId)
		response := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			Boperator:          boperator,
			CreateAt:           Time,
			NickName:           nickname,
			HeadUrl:            headurl,
			ISCoop:             Iscoop,
			Sprojectid:         task.SLocalLifeId,
			City:               task.City,
		}
		taskInfoPointers = append(taskInfoPointers, response)
	}

	return &http_model.GetLocalTaskListData{
		TaskList: taskInfoPointers,
		Total:    conv.MustString(total, ""),
	}, nil
}

func PassLocalTaskCoop(ctx context.Context, req http_model.PasslocalTaskCoopRequest) (bool, error) {
	db := GetReadDB(ctx)
	var count int64
	fmt.Println("task_ids: ", req.TaskIds)
	err := db.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id IN ? AND task_stage = 1", req.TaskIds).Count(&count).Error

	fmt.Println("count: ", count)
	if err != nil {
		return false, err
	}
	if int64(len(req.TaskIds)) == 0 || count != int64(len(req.TaskIds)) {
		return false, errors.New("任务id有误")
	}

	// 2. 查询任务对应达人id（用于生成达人消息）
	var talentIds []string
	err = db.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id IN ?", req.TaskIds).Select("talent_id").Find(&talentIds).Error
	if err != nil {
		return false, err
	}

	// 3. 查询任务对应project名称（用于生成达人消息）
	var project gorm_model.YounggeeLocalLifeInfo
	err = db.Model(gorm_model.YounggeeLocalLifeInfo{}).Where("local_id = ?", req.ProjectId).Find(&project).Error
	if err != nil {
		return false, err
	}

	var taskstages int
	if project.TaskForm == 1 {
		taskstages = 4
	} else {
		taskstages = 9
	}

	nextstage := [6]int{0, 0, 0, 0, 0, 0} // 数组长度为6，表示6种工具 4,9,11,13
	if req.IsSpecial == 1 {
		toolList := strings.Split(project.Tools, ",")
		for _, tool := range toolList {
			// 将 tool 转换为整数
			if t, err := strconv.Atoi(tool); err == nil && t >= 0 && t <= len(nextstage) {
				nextstage[t-1] = 1
			}
		}
		fmt.Println(nextstage)
		for i := 1; i < len(nextstage); i++ { // 从位置1开始
			if nextstage[i] == 1 {
				switch i {
				case 1:
					taskstages = 4
				case 2:
					taskstages = 9
				case 3:
					taskstages = 11
				case 4:
					taskstages = 13
				case 5:
					taskstages = 15
				}
				break
			}
		}
	}

	//4.根据达人来源改变状态、阶段、数目
	var tasks []gorm_model.YoungeeLocalTaskInfo
	err = db.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id IN ? AND task_stage = 1", req.TaskIds).Find(&tasks).Error
	if err != nil {
		return false, err
	}
	err = db.Transaction(func(tx *gorm.DB) error {
		// 2. 修改任务状态和任务阶段
		for _, taskInfo := range tasks {
			if taskInfo.SupplierId != 0 && taskInfo.SupplierStatus == 2 { //服务商招募数量+1
				updateData := gorm_model.YoungeeLocalTaskInfo{
					TaskStage:     taskstages,
					TaskStatus:    2,
					UpdateAt:      time.Now(),
					BOperator:     req.OperatorId,
					BOperatorType: req.OperateType,
					SelectDate:    time.Now(),
				}
				err = tx.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id = ? AND task_stage = 1", taskInfo.TaskId).Updates(updateData).Error
				if err != nil {
					return err
				}

				//project招募数+1,预估成本+服务商价格
				var projectinfo gorm_model.YounggeeLocalLifeInfo
				err = db.Model(gorm_model.YounggeeLocalLifeInfo{}).Where("local_id = ?", req.ProjectId).Find(&projectinfo).Error
				if err != nil {
					return err
				}
				projectinfo.RecruitNum += 1
				projectinfo.EstimatedCost += taskInfo.SupportFee
				err = tx.Model(gorm_model.YounggeeLocalLifeInfo{}).Where("local_id = ? ", req.ProjectId).Updates(projectinfo).Error
				if err != nil {
					return err
				}
				//服务商s_project已招募人数+1改成s_locallife
				var sprojectinfo gorm_model.YounggeeSProjectInfo
				err = db.Model(gorm_model.YounggeeSProjectInfo{}).Where(" s_project_id =?", req.SProjectId).Find(&sprojectinfo).Error
				if err != nil {
					return err
				}
				sprojectinfo.RecruitNum += 1
				fmt.Println("......", projectinfo.RecruitNum)
				err = tx.Model(gorm_model.YounggeeSProjectInfo{}).Where(" s_project_id =?", req.SProjectId).Updates(sprojectinfo).Error
				if err != nil {
					return err
				} //

			}

			//if project.TaskForm != 1 { //素材分发
			//	var draft_default gorm_model.InfoAutoTask
			//	err = db.Model(gorm_model.InfoAutoTask{}).Where("auto_task_id = ?", project.AutoTaskId).Find(&draft_default).Error
			//	if err != nil {
			//		return err
			//	}
			//	duration := time.Duration(draft_default.DraftDefault) * time.Hour
			//	upbreakdate := gorm_model.YoungeeLocalTaskInfo{
			//		CurBreakAt: time.Now().Add(duration),
			//	}
			//	err = tx.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id = ? ", taskInfo.TaskId).Updates(upbreakdate).Error
			//	if err != nil {
			//		return err
			//	}
			//}

			if taskInfo.SupplierId == 0 && taskInfo.SupplierStatus == 0 { //来源于公海
				updateData := gorm_model.YoungeeLocalTaskInfo{
					TaskStage:     taskstages,
					TaskStatus:    2,
					UpdateAt:      time.Now(),
					BOperator:     req.OperatorId,
					BOperatorType: req.OperateType,
					SelectDate:    time.Now(),
				}
				err = tx.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id = ? AND task_stage = 1", taskInfo.TaskId).Updates(updateData).Error
				if err != nil {
					return err
				}

				//project招募数+1
				var projectinfo gorm_model.YounggeeLocalLifeInfo
				err = db.Model(gorm_model.YounggeeLocalLifeInfo{}).Where("local_id = ?", req.ProjectId).Find(&projectinfo).Error
				if err != nil {
					return err
				}
				projectinfo.RecruitNum += 1
				err = tx.Model(gorm_model.YounggeeLocalLifeInfo{}).Where("local_id = ? ", req.ProjectId).Updates(projectinfo).Error
				if err != nil {
					return err
				}
			}

		}
		// 4. 生成达人消息
		for _, talendId := range talentIds {
			err = CreateMessage(ctx, 1, 1, talendId, project.LocalName)
			if err != nil {
				return err
			}
		}
		// 返回 nil 提交事务
		return nil
	})
	if err != nil {
		return false, err
	}
	return true, nil
}

func RefuseLocalTaskCoop(ctx context.Context, req http_model.RefuselocalTaskCoopRequest) (bool, error) {
	db := GetWriteDB(ctx)
	// 1. 校验
	var count int64
	err := db.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id IN ? AND task_stage = 1", req.TaskIds).Count(&count).Error
	if err != nil {
		return false, err
	}
	if count != int64(len(req.TaskIds)) {
		return false, errors.New("任务id有误")
	}

	// 2. 查询任务对应达人id（用于生成达人消息）
	var talentIds []string
	err = db.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id IN ?", req.TaskIds).Select("talent_id").Find(&talentIds).Error
	if err != nil {
		return false, err
	}

	var tasks []gorm_model.YoungeeLocalTaskInfo
	err = db.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id IN ? AND task_stage = 1", req.TaskIds).Find(&tasks).Error

	err = db.Transaction(func(tx *gorm.DB) error {
		// 2. 修改任务状态和任务阶段
		for _, taskInfo := range tasks {
			updateData := gorm_model.YoungeeLocalTaskInfo{
				TaskStage:     3,
				TaskStatus:    3,
				UpdateAt:      time.Now(),
				BOperator:     req.OperatorId,
				BOperatorType: req.OperateType,
				CompleteDate:  time.Now(),
			}
			err = tx.Model(gorm_model.YoungeeLocalTaskInfo{}).Where("task_id = ? AND task_stage = 1", taskInfo.TaskId).Updates(updateData).Error
		}
		if err != nil {
			return err
		}

		// 返回 nil 提交事务
		return nil
	})
	if err != nil {
		return false, err
	}
	return true, nil
}

func UpdateLocallife(ctx context.Context, project gorm_model.YounggeeLocalLifeInfo) (*string, error) {
	db := GetReadDB(ctx)
	err := db.Model(&project).Updates(project).Error
	if err != nil {
		return nil, err
	}
	return &project.LocalId, nil
}

func GetLocalPreSketchList(ctx context.Context, request http_model.LocalPreSketchListRequest) (*http_model.GetLocalSketchTaskListData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_stage = ?", request.ProjectId, request.ScriptStatus)
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize
	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocalTasksketchInfo, 0, len(projecrtaskinfo))

	for _, task := range projecrtaskinfo {
		nickname, headurl := getTalentinfo(db, task.TalentId)
		Iscoop := getIscoop(db, task.TalentId, request.EnterpriseId)
		taskinfo := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			NickName:           nickname,
			HeadUrl:            headurl,
			ISCoop:             Iscoop,
			City:               task.City,
		}
		response := &http_model.LocalTasksketchInfo{
			Task: taskinfo,
			DDl:  task.CurBreakAt,
		}
		taskInfoPointers = append(taskInfoPointers, response)

	}
	return &http_model.GetLocalSketchTaskListData{
		TasksketchList: taskInfoPointers,
		Total:          conv.MustString(total, ""),
	}, nil
}

func GetLocalSketchList(ctx context.Context, request http_model.LocalTasksketchlistRequest) (*http_model.GetsketchlocaltaskListData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_stage = ?", request.ProjectId, request.ScriptStatus)
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize
	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocalTasksketchinfo, 0, len(projecrtaskinfo))
	for _, task := range projecrtaskinfo {
		nickname, headurl := getTalentinfo(db, task.TalentId)
		taskinfo := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			NickName:           nickname,
			HeadUrl:            headurl,
			City:               task.City,
		}
		var sketchinfo gorm_model.YounggeeSketchInfo
		err := db.Model(&gorm_model.YounggeeSketchInfo{}).Where("task_id = ? and is_review = 0", task.TaskId).First(&sketchinfo).Error
		if err != nil {
			return nil, err
		}
		boperator := getBOperator(db, task.BOperator, task.BOperatorType)
		response := &http_model.LocalTasksketchinfo{
			Task:     taskinfo,
			SketchId: sketchinfo.SketchID,
			SubmitAt: sketchinfo.SubmitAt,
			AgreeAt:  sketchinfo.AgreeAt,
			Operator: boperator,
		}
		taskInfoPointers = append(taskInfoPointers, response)

	}
	return &http_model.GetsketchlocaltaskListData{
		LocalTasksketchList: taskInfoPointers,
		Total:               conv.MustString(total, ""),
	}, nil
}

func GetLocalPreLinkList(ctx context.Context, request http_model.LocalPreLinkListRequest) (*http_model.GetLocalPreLinkListData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_stage = ?", request.ProjectId, request.LinkStatus)
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize
	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocalTasklinkinfo, 0, len(projecrtaskinfo))
	for _, task := range projecrtaskinfo {
		nickname, headurl := getTalentinfo(db, task.TalentId)
		Iscoop := getIscoop(db, task.TalentId, request.EnterpriseId)
		taskinfo := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			NickName:           nickname,
			HeadUrl:            headurl,
			ISCoop:             Iscoop,
			City:               task.City,
		}
		response := &http_model.LocalTasklinkinfo{
			Task: taskinfo,
			DDl:  task.CurBreakAt,
		}
		taskInfoPointers = append(taskInfoPointers, response)

	}
	return &http_model.GetLocalPreLinkListData{
		TasklinkList: taskInfoPointers,
		Total:        conv.MustString(total, ""),
	}, nil
}

func GetLocalLinkList(ctx context.Context, request http_model.LocalTaskLinklistRequest) (*http_model.GetLocalTaskLinkListData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_stage = ?", request.ProjectId, request.LinkStatus)
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize
	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocalTaskLinkinfo, 0, len(projecrtaskinfo))
	for _, task := range projecrtaskinfo {
		nickname, headurl := getTalentinfo(db, task.TalentId)
		Iscoop := getIscoop(db, task.TalentId, request.EnterpriseId)
		taskinfo := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			NickName:           nickname,
			HeadUrl:            headurl,
			ISCoop:             Iscoop,
			City:               task.City,
		}
		var linkinfo gorm_model.YounggeeLinkInfo
		err := db.Model(&gorm_model.YounggeeLinkInfo{}).Where("task_id = ? and is_review = 0", task.TaskId).First(&linkinfo).Error
		if err != nil {
			return nil, err
		}
		boperator := getBOperator(db, task.BOperator, task.BOperatorType)
		response := &http_model.LocalTaskLinkinfo{
			Task:     taskinfo,
			LinkId:   linkinfo.LinkID,
			SubmitAt: linkinfo.SubmitAt,
			AgreeAt:  linkinfo.AgreeAt,
			LinkUrl:  linkinfo.LinkUrl,
			PhotoUrl: linkinfo.PhotoUrl,
			Operator: boperator,
		}
		taskInfoPointers = append(taskInfoPointers, response)

	}
	return &http_model.GetLocalTaskLinkListData{
		LocalTaskLinklist: taskInfoPointers,
		Total:             conv.MustString(total, ""),
	}, nil
}

func GetLocalPreDataList(ctx context.Context, request http_model.LocalPreDataListRequest) (*http_model.GetLocalPreDataListData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_stage = ?", request.ProjectId, request.DataStatus)
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize
	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocalTaskdatainfo, 0, len(projecrtaskinfo))
	for _, task := range projecrtaskinfo {
		nickname, headurl := getTalentinfo(db, task.TalentId)
		Iscoop := getIscoop(db, task.TalentId, request.EnterpriseId)
		taskinfo := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			NickName:           nickname,
			HeadUrl:            headurl,
			ISCoop:             Iscoop,
			City:               task.City,
		}
		response := &http_model.LocalTaskdatainfo{
			Task: taskinfo,
			DDl:  task.CurBreakAt,
		}
		taskInfoPointers = append(taskInfoPointers, response)

	}
	return &http_model.GetLocalPreDataListData{
		TaskdataList: taskInfoPointers,
		Total:        conv.MustString(total, ""),
	}, nil
}

func GetLocalDataList(ctx context.Context, request http_model.LocalTaskDatalistRequest) (*http_model.GetLocalTaskDatalistData, error) {
	db := GetReadDB(ctx)
	var projecrtaskinfo []gorm_model.YoungeeLocalTaskInfo
	query := db.Model(&gorm_model.YoungeeLocalTaskInfo{}).Where("local_id = ? AND task_stage = ?", request.ProjectId, request.DataStatus)
	// 计算总数
	var total int64
	if err := query.Count(&total).Error; err != nil {
		return nil, err
	}

	// 添加分页逻辑
	pageSize := request.PageSize
	if pageSize == 0 {
		pageSize = 10
	}
	pageNum := request.PageNum
	if pageNum == 0 {
		pageNum = 1
	}
	offset := (pageNum - 1) * pageSize
	// 执行分页查询
	if err := query.Offset(offset).Limit(pageSize).Find(&projecrtaskinfo).Error; err != nil {
		return nil, err
	}
	taskInfoPointers := make([]*http_model.LocalTaskDatainfo, 0, len(projecrtaskinfo))
	for _, task := range projecrtaskinfo {
		nickname, headurl := getTalentinfo(db, task.TalentId)
		Iscoop := getIscoop(db, task.TalentId, request.EnterpriseId)
		taskinfo := &http_model.LocaLTaskInfo{
			TaskId:             task.TaskId,
			ProjectId:          task.LocalId,
			TalentId:           task.TalentId,
			FansNum:            task.FansNum,
			DraftFee:           task.DraftFee,
			Voteavg:            task.VoteAvg,
			FeeFrom:            task.FeeForm,
			TaskStage:          task.TaskStage,
			Commentavg:         task.CommitAvg,
			CurrentDefaultType: task.CurDefaultType,
			From:               determineFrom(task.SupplierId, task.SupplierStatus),
			NickName:           nickname,
			HeadUrl:            headurl,
			ISCoop:             Iscoop,
			City:               task.City,
		}
		var datainfo gorm_model.YounggeeDataInfo
		err := db.Model(&gorm_model.YounggeeDataInfo{}).Where("task_id = ? and is_review = 0", task.TaskId).First(&datainfo).Error
		if err != nil {
			return nil, err
		}
		boperator := getBOperator(db, task.BOperator, task.BOperatorType)
		response := &http_model.LocalTaskDatainfo{
			Task:          taskinfo,
			DataId:        datainfo.DataID,
			SubmitAt:      datainfo.SubmitAt,
			AgreeAt:       datainfo.AgreeAt,
			PhotoUrl:      datainfo.PhotoUrl,
			PlayNumber:    datainfo.PlayNumber,
			LikeNumber:    datainfo.LikeNumber,
			CollectNumber: datainfo.CollectNumber,
			CommentNumber: datainfo.CommentNumber,
			SettleAmount:  task.SettleAmount,
			Breakrate:     task.SketchBreakRate + task.LinkBreakRate + task.DataBreakRate,
			Operator:      boperator,
		}
		taskInfoPointers = append(taskInfoPointers, response)

	}
	return &http_model.GetLocalTaskDatalistData{
		LocalTaskDatalist: taskInfoPointers,
		Total:             conv.MustString(total, ""),
	}, nil
}
